==> hbshare-3.6.72.tar.gz: hbshare-3.6.72/hbshare/quant/CChen/cta_factor/const.py <==
composite_factor = {
    'tsmom_dzq': [
        'tsmom_d3',
        'tsmom_d5'
    ],
    'tsmom_zzq': [
        'tsmom_d10',
        'tsmom_d20',
        'tsmom_d30'
    ],
    'tsmom_czq': [
        'tsmom_d60',
        'tsmom_d250',
    ],
    'xsmom_dzq': [
        'xsmom_d3_q75',
        'xsmom_d5_q75'
    ],
    'xsmom_zzq': [
        'xsmom_d10_q75',
        'xsmom_d20_q75',
        'xsmom_d30_q75'
    ],
    'xsmom_czq': [
        'xsmom_d60_q75',
        'xsmom_d250_q75',
    ],
    'qxjg': [
        'carry_d20_q70',
        'tscarry_d50',
    ],
    'tsbasismom_dzq': [
        'tsbasismom_d3',
        'tsbasismom_d5'
    ],
    'tsbasismom_zzq': [
        'tsbasismom_d10',
        'tsbasismom_d20',
        'tsbasismom_d30'
    ],
}

stock_data_indicator = {
    'A': [
        'S0049489'  # 注册仓单量:豆一
    ],
    'AG': [
        'S0114146',  # COMEX:银:库存
        'S0174909',  # 库存期货:白银
    ],
    'AL': [
        'S0029756',  # 总库存:LME铝
        'S0049494',  # 库存期货:铝
        'S0049509',  # 库存小计:铝:总计
        'S9900014',  # 现货库存:电解铝:合计
    ],
    'AU': [
        'S0049497',  # 库存期货:黄金
        'S0114145',	 # COMEX:黄金:库存
    ],
    'B': [
        'S0117164',  # 港口库存:进口大豆
        'S0181988',  # 注册仓单量:豆二
    ],
    'BU': [
        'S0204801',  # 库存期货:沥青:仓库:总计
        'S0204802',  # 库存期货:沥青:厂库:总计
        'S0204843',  # 库存小计:沥青:仓库:总计
        'S0204863',  # 库存小计:沥青:总计
        'S5469615',  # 厂家库存:沥青:国内
        'S5469833',  # 社会库存:沥青:国内
    ],
    'C': [
        'S0049491',  # 注册仓单量:黄玉米
        'S5063274',  # 玉米:北方库存
        'S5063275',  # 玉米:南方库存
    ],
    'CF': [
        'S0049502',  # 仓单数量:一号棉花
    ],
    'CJ': [
        'S0268793',  # 仓单数量:红枣
    ],
    'CS': [
        'S0243229',  # 注册仓单量:玉米淀粉
    ],
    'CU': [
        'S0029752',  # 总库存:LME铜
        'S0049493',  # 库存期货:阴极铜
        'S0049507',  # 库存小计:阴极铜:总计
        'S0114144',  # COMEX:铜:库存
        'S5811269',  # 库存:铜:上海其他仓库
        'S5811270',  # 库存:铜:上海保税区
        'S5811271',  # 库存:铜:广东
        'S5811272',  # 库存:铜:江苏
        'S5811565',  # 库存:铜:重庆
        'S5811566',  # 库存:铜:天津
    ],
    'EB': [
        'S0270917',  # 注册仓单量:苯乙烯:合计
        'S5475752',  # 港口库存:苯乙烯:华东
        'S5475754',  # 港口库存:苯乙烯:华南
        'S5475756',  # 工厂库存:苯乙烯:全国估计
    ],
    'EG': [
        'S0270950',  # 注册仓单量:乙二醇:合计
        'S5444186',  # 库存:乙二醇:浙江、江苏港合计
    ],
    'FG': [
        'S0180504',  # 仓单数量:玻璃
    ],
    'FU': [
        'S0049496',  # 库存期货:燃料油
        'S0049510',  # 库存小计:燃料油:总计
        'S5118238',  # 燃料油库存:轻质馏分油:新加坡
        'S5118239',  # 燃料油库存:中质馏分油:新加坡
    ],
    'HC': [
        'L2776415',  # 主要钢厂库存:热轧板卷:当周值
        'S0212531',  # 库存期货:热轧卷板
        'X1924001',  # 社会库存:热轧板卷
    ],
    'I': [
        'S0110152',  # 库存:铁矿石:港口合计
        'S0255299',  # 注册仓单量:铁矿石
        # 'S5716160',  # 进口矿平均可用天数
    ],
    'J': [
        'S0180501',  # 注册仓单量:焦炭
        'S5133392',  # 焦炭总库存:焦化企业(230家):产能<100万吨
        'S5133393',  # 焦炭总库存:焦化企业(230家):产能100-200万吨
        'S5133394',  # 焦炭总库存:焦化企业(230家):产能>200万吨
        'S5133852',  # 焦炭库存:国内样本钢厂(247家):合计
        'S5716616',  # 焦炭库存:港口总计
    ],
    'JD': [
        'S0205142',  # 注册仓单量:鸡蛋
    ],
    'JM': [
        'S0204796',  # 注册仓单量:焦煤:合计
        'S5125686',  # 炼焦煤库存:六港口合计
        'S5133418',  # 炼焦煤总库存:国内独立焦化厂(230家):合计
        'S5133868',  # 炼焦煤库存:国内样本钢厂(247家)
    ],
    'L': [
        'S0164028',  # 注册仓单量:聚乙烯(LLDPE):合计
        'S5475033',  # 库存:聚烯烃:石化库存
    ],
    'LU': [
        'S0272660',  # 库存期货:INE低硫燃料油:仓库:总计
        'S0272661',  # 库存期货:INE低硫燃料油:厂库:总计
    ],
    'M': [
        'S0049490',  # 注册仓单量:豆粕
    ],
    'MA': [
        'S0174911',  # 仓单数量:甲醇
        'S5444138',  # 库存:甲醇:宁波港口(含禾元自有货源)
        'S5444139',  # 库存:甲醇:江苏港口
        'S5444140',  # 库存:甲醇:华南港口
        'S5448404',  # 库存:甲醇:广东港口
        'S5448405',  # 库存:甲醇:福建港口
        'S5458282',  # 库存:甲醇:华北地区
        'S5458284',  # 库存:甲醇:华中地区
        'S5458285',  # 库存:甲醇:西北地区
        'S5458286',  # 库存:甲醇:东北地区
        'S5458287',  # 库存:甲醇:西南地区
        'S5475759',  # 库存:甲醇:华东地区
    ],
    'NI': [
        'S0029772',  # 总库存:LME镍
        'S0110153',  # 库存:镍矿:港口合计(10港口)
        'S0213018',  # 库存期货:镍
        'S0213020',  # 库存小计:镍:总计
    ],
    'NR': [
        'S0269071',  # 库存期货:INE20号胶:总计
        'S0269085',  # 库存小计:INE20号胶:总计
    ],
    'OI': [
        'S0049503',  # 仓单数量:菜籽油
    ],
    'P': [
        'S0149298',  # 注册仓单量:棕榈油
        'S5029336',  # 棕榈油:商业库存:全国
    ],
    'PB': [
        'S0029764',  # 总库存:LME铅
        'S0167707',  # 库存小计:铅:总计
        'S0167708',  # 库存期货:铅
    ],
    'PF': [
        # 'S5448962',  # 库存天数:涤纶短纤:国内
        'S0272713',  # 仓单数量:短纤
    ],
    'PP': [
        'S0205112',  # 注册仓单量:聚丙烯
    ],
    'RB': [
        'H6924748',  # 社会库存:螺纹钢
        'R8579706',  # 主要钢厂库存:螺纹钢:当周值
        'S0114168',  # 库存小计:螺纹钢:总计
        'S0114170',  # 库存期货:螺纹钢
    ],
    'RM': [
        'S0180505',  # 仓单数量:菜籽粕
    ],
    'RU': [
        'S0163822',  # 库存小计:天然橡胶:总计
        'S0163835',  # 库存期货:天然橡胶:总计
    ],
    'SA': [
        'S0270905',  # 仓单数量:纯碱
        'S5479786',  # 库存:纯碱:全国
    ],
    'SC': [
        'S0069595',  # 库存量:原油和石油产品(包括战略石油储备)
        'S0069596',  # 库存量:原油和石油产品(不包括战略石油储备)
        'S0069597',  # 库存量:商业原油:全美
        'S0265093',  # 库存期货:INE原油
    ],
    'SF': [
        'S0212534',  # 仓单数量:硅铁
    ],
    'SM': [
        'S0212536',  # 仓单数量:锰硅
    ],
    'SN': [
        'S0029768',  # 总库存:LME锡
        'S0213019',  # 库存期货:锡
        'S0213021',  # 库存小计:锡:总计
    ],
    'SP': [
        'S0267633',  # 库存小计:纸浆:总计
        'S0267634',  # 库存期货:纸浆:总计
    ],
    'SR': [
        'S0049500',  # 仓单数量:白砂糖
    ],
    'SS': [
        'A6872309',  # 库存期货:不锈钢
        'S5708345',  # 库存:不锈钢:300系:合计:佛山
        'S5708357',  # 库存:不锈钢:300系:合计:无锡
    ],
    'TA': [
        'S0049499',  # 仓单数量:PTA
        # 'S5446169',  # 库存天数:PTA:国内
    ],
    'UR': [
        'S0270888',  # 仓单数量:尿素
        'S5458274',  # 库存:尿素:烟台港
        'S5458275',  # 库存:尿素:青岛大港
        'S5458276',  # 库存:尿素:日照港
        'S5458277',  # 库存:尿素:莱州港
        'S5458279',  # 库存:尿素:锦州港
        'S5458280',  # 库存:尿素:秦皇岛港
        'S5458281',  # 库存:尿素:天津港
    ],
    'V': [
        'S0180500',  # 注册仓单量:PVC
        'S5471265',  # 社会库存:PVC
        'S5475847',  # 库存:聚氯乙烯(PVC):华东
        'S5475850',  # 库存:聚氯乙烯(PVC):华南
    ],
    'Y': [
        'S0049488',  # 注册仓单量:豆油
        'S5063139',  # 港口库存:豆油:全国
    ],
    'ZC': [
        'D7901707',  # 仓单数量:动力煤
        'S5103725',  # 煤炭库存:秦皇岛港
    ],
    'ZN': [
        'S0029760',  # 总库存:LME锌
        'S0049498',  # 库存期货:锌
        'S0049506',  # 库存小计:锌:总计
        'S5811181',  # 库存:锌锭:合计
    ]
}

==> hbshare-3.6.81.tar.gz: hbshare-3.6.81/hbshare/quant/CChen/cta_factor/const.py <==
composite_factor = {
    'tsmom_dzq': [
        'tsmom_d3',
        'tsmom_d5'
    ],
    'tsmom_zzq': [
        'tsmom_d10',
        'tsmom_d20',
        'tsmom_d30'
    ],
    'tsmom_czq': [
        'tsmom_d60',
        'tsmom_d250',
    ],
    'xsmom_dzq': [
        'xsmom_d3_q75',
        'xsmom_d5_q75'
    ],
    'xsmom_zzq': [
        'xsmom_d10_q75',
        'xsmom_d20_q75',
        'xsmom_d30_q75'
    ],
    'xsmom_czq': [
        'xsmom_d60_q75',
        'xsmom_d250_q75',
    ],
    'qxjg': [
        'carry_d20_q70',
        'tscarry_d50',
    ],
    'tsbasismom_dzq': [
        'tsbasismom_d3',
        'tsbasismom_d5'
    ],
    'tsbasismom_zzq': [
        'tsbasismom_d10',
        'tsbasismom_d20',
        'tsbasismom_d30'
    ],
}

stock_data_indicator = {
    'A': [
        'S0049489'  # 注册仓单量:豆一
    ],
    'AG': [
        'S0114146',  # COMEX:银:库存
        'S0174909',  # 库存期货:白银
    ],
    'AL': [
        'S0029756',  # 总库存:LME铝
        'S0049494',  # 库存期货:铝
        'S0049509',  # 库存小计:铝:总计
        'S9900014',  # 现货库存:电解铝:合计
    ],
    'AU': [
        'S0049497',  # 库存期货:黄金
        'S0114145',	 # COMEX:黄金:库存
    ],
    'B': [
        'S0117164',  # 港口库存:进口大豆
        'S0181988',  # 注册仓单量:豆二
    ],
    'BU': [
        'S0204801',  # 库存期货:沥青:仓库:总计
        'S0204802',  # 库存期货:沥青:厂库:总计
        'S0204843',  # 库存小计:沥青:仓库:总计
        # 'S0204863',  # 库存小计:沥青:总计
        'S5469615',  # 厂家库存:沥青:国内
        'S5469833',  # 社会库存:沥青:国内
    ],
    'C': [
        'S0049491',  # 注册仓单量:黄玉米
        'S5063274',  # 玉米:北方库存
        'S5063275',  # 玉米:南方库存
    ],
    'CF': [
        'S0049502',  # 仓单数量:一号棉花
    ],
    'CJ': [
        'S0268793',  # 仓单数量:红枣
    ],
    'CS': [
        'S0243229',  # 注册仓单量:玉米淀粉
    ],
    'CU': [
        'S0029752',  # 总库存:LME铜
        'S0049493',  # 库存期货:阴极铜
        'S0049507',  # 库存小计:阴极铜:总计
        'S0114144',  # COMEX:铜:库存
        'S5811269',  # 库存:铜:上海其他仓库
        'S5811270',  # 库存:铜:上海保税区
        'S5811271',  # 库存:铜:广东
        'S5811272',  # 库存:铜:江苏
        'S5811565',  # 库存:铜:重庆
        'S5811566',  # 库存:铜:天津
    ],
    'EB': [
        'S0270917',  # 注册仓单量:苯乙烯:合计
        'S5475752',  # 港口库存:苯乙烯:华东
        'S5475754',  # 港口库存:苯乙烯:华南
        'S5475756',  # 工厂库存:苯乙烯:全国估计
    ],
    'EG': [
        'S0270950',  # 注册仓单量:乙二醇:合计
        'S5444186',  # 库存:乙二醇:浙江、江苏港合计
    ],
    'FG': [
        'S0180504',  # 仓单数量:玻璃
    ],
    'FU': [
        'S0049496',  # 库存期货:燃料油
        'S0049510',  # 库存小计:燃料油:总计
        'S5118238',  # 燃料油库存:轻质馏分油:新加坡
        'S5118239',  # 燃料油库存:中质馏分油:新加坡
    ],
    'HC': [
        'L2776415',  # 主要钢厂库存:热轧板卷:当周值
        'S0212531',  # 库存期货:热轧卷板
        'X1924001',  # 社会库存:热轧板卷
    ],
    'I': [
        'S0110152',  # 库存:铁矿石:港口合计
        'S0255299',  # 注册仓单量:铁矿石
        # 'S5716160',  # 进口矿平均可用天数
    ],
    'J': [
        'S0180501',  # 注册仓单量:焦炭
        'S5133392',  # 焦炭总库存:焦化企业(230家):产能<100万吨
        'S5133393',  # 焦炭总库存:焦化企业(230家):产能100-200万吨
        'S5133394',  # 焦炭总库存:焦化企业(230家):产能>200万吨
        'S5133852',  # 焦炭库存:国内样本钢厂(247家):合计
        'S5716616',  # 焦炭库存:港口总计
    ],
    'JD': [
        'S0205142',  # 注册仓单量:鸡蛋
    ],
    'JM': [
        'S0204796',  # 注册仓单量:焦煤:合计
        'S5125686',  # 炼焦煤库存:六港口合计
        'S5133418',  # 炼焦煤总库存:国内独立焦化厂(230家):合计
        'S5133868',  # 炼焦煤库存:国内样本钢厂(247家)
    ],
    'L': [
        'S0164028',  # 注册仓单量:聚乙烯(LLDPE):合计
        'S5475033',  # 库存:聚烯烃:石化库存
    ],
    'LU': [
        'S0272660',  # 库存期货:INE低硫燃料油:仓库:总计
        'S0272661',  # 库存期货:INE低硫燃料油:厂库:总计
    ],
    'M': [
        'S0049490',  # 注册仓单量:豆粕
    ],
    'MA': [
        'S0174911',  # 仓单数量:甲醇
        'S5444138',  # 库存:甲醇:宁波港口(含禾元自有货源)
        'S5444139',  # 库存:甲醇:江苏港口
        'S5444140',  # 库存:甲醇:华南港口
        'S5448404',  # 库存:甲醇:广东港口
        'S5448405',  # 库存:甲醇:福建港口
        'S5458282',  # 库存:甲醇:华北地区
        'S5458284',  # 库存:甲醇:华中地区
        'S5458285',  # 库存:甲醇:西北地区
        'S5458286',  # 库存:甲醇:东北地区
        'S5458287',  # 库存:甲醇:西南地区
        'S5475759',  # 库存:甲醇:华东地区
    ],
    'NI': [
        'S0029772',  # 总库存:LME镍
        'S0110153',  # 库存:镍矿:港口合计(10港口)
        'S0213018',  # 库存期货:镍
        'S0213020',  # 库存小计:镍:总计
    ],
    'NR': [
        'S0269071',  # 库存期货:INE20号胶:总计
        'S0269085',  # 库存小计:INE20号胶:总计
    ],
    'OI': [
        'S0049503',  # 仓单数量:菜籽油
    ],
    'P': [
        'S0149298',  # 注册仓单量:棕榈油
        'S5029336',  # 棕榈油:商业库存:全国
    ],
    'PB': [
        'S0029764',  # 总库存:LME铅
        'S0167707',  # 库存小计:铅:总计
        'S0167708',  # 库存期货:铅
    ],
    'PF': [
        # 'S5448962',  # 库存天数:涤纶短纤:国内
        'S0272713',  # 仓单数量:短纤
    ],
    'PP': [
        'S0205112',  # 注册仓单量:聚丙烯
    ],
    'RB': [
        'K4569350',  # 社会库存:螺纹钢
        'R8579706',  # 主要钢厂库存:螺纹钢:当周值
        # 'S0114168',  # 库存小计:螺纹钢:总计
        'S0114170',  # 库存期货:螺纹钢
    ],
    'RM': [
        'S0180505',  # 仓单数量:菜籽粕
    ],
    'RU': [
        'S0163822',  # 库存小计:天然橡胶:总计
        'S0163835',  # 库存期货:天然橡胶:总计
    ],
    'SA': [
        'S0270905',  # 仓单数量:纯碱
        'S5479786',  # 库存:纯碱:全国
    ],
    'SC': [
        'S0069595',  # 库存量:原油和石油产品(包括战略石油储备)
        'S0069596',  # 库存量:原油和石油产品(不包括战略石油储备)
        'S0069597',  # 库存量:商业原油:全美
        'S0265093',  # 库存期货:INE原油
    ],
    'SF': [
        'S0212534',  # 仓单数量:硅铁
    ],
    'SM': [
        'S0212536',  # 仓单数量:锰硅
    ],
    'SN': [
        'S0029768',  # 总库存:LME锡
        'S0213019',  # 库存期货:锡
        'S0213021',  # 库存小计:锡:总计
    ],
    'SP': [
        'S0267633',  # 库存小计:纸浆:总计
        'S0267634',  # 库存期货:纸浆:总计
    ],
    'SR': [
        'S0049500',  # 仓单数量:白砂糖
    ],
    'SS': [
        'A6872309',  # 库存期货:不锈钢
        'S5708345',  # 库存:不锈钢:300系:合计:佛山
        'S5708357',  # 库存:不锈钢:300系:合计:无锡
    ],
    'TA': [
        'S0049499',  # 仓单数量:PTA
        # 'S5446169',  # 库存天数:PTA:国内
    ],
    'UR': [
        'S0270888',  # 仓单数量:尿素
        'S5458274',  # 库存:尿素:烟台港
        'S5458275',  # 库存:尿素:青岛大港
        'S5458276',  # 库存:尿素:日照港
        'S5458277',  # 库存:尿素:莱州港
        'S5458279',  # 库存:尿素:锦州港
        'S5458280',  # 库存:尿素:秦皇岛港
        'S5458281',  # 库存:尿素:天津港
    ],
    'V': [
        'S0180500',  # 注册仓单量:PVC
        'S5471265',  # 社会库存:PVC
        'S5475847',  # 库存:聚氯乙烯(PVC):华东
        'S5475850',  # 库存:聚氯乙烯(PVC):华南
    ],
    'Y': [
        'S0049488',  # 注册仓单量:豆油
        'S5063139',  # 港口库存:豆油:全国
    ],
    'ZC': [
        'D7901707',  # 仓单数量:动力煤
        'S5103725',  # 煤炭库存:秦皇岛港
    ],
    'ZN': [
        'S0029760',  # 总库存:LME锌
        'S0049498',  # 库存期货:锌
        'S0049506',  # 库存小计:锌:总计
        'S5811181',  # 库存:锌锭:合计
    ]
}
